@@ -5,14 +5,9 @@ from apiclient.authentication_methods import (
     NoAuthentication,
     QueryParameterAuthentication,
 )
-from apiclient.client import APIClient, BaseClient
+from apiclient.client import APIClient
 from apiclient.decorates import endpoint
 from apiclient.paginators import paginated
 from apiclient.request_formatters import JsonRequestFormatter
-from apiclient.response_handlers import (
-    JsonResponseHandler,
-    RequestsResponseHandler,
-    XmlResponseHandler,
-    YamlResponseHandler,
-)
+from apiclient.response_handlers import JsonResponseHandler, RequestsResponseHandler, XmlResponseHandler
 from apiclient.retrying import retry_request
